[Python-checkins] r66457 - in python/trunk/Misc: NEWS find_recursionlimit.py

antoine.pitrou python-checkins at python.org
Sat Sep 13 22:30:30 CEST 2008


Author: antoine.pitrou
Date: Sat Sep 13 22:30:30 2008
New Revision: 66457

Log:
Issue #3850: Misc/find_recursionlimit.py was broken.

Reviewed by A.M. Kuchling.



Modified:
   python/trunk/Misc/NEWS
   python/trunk/Misc/find_recursionlimit.py

Modified: python/trunk/Misc/NEWS
==============================================================================
--- python/trunk/Misc/NEWS	(original)
+++ python/trunk/Misc/NEWS	Sat Sep 13 22:30:30 2008
@@ -15,6 +15,14 @@
 Library
 -------
 
+Tools/Demos
+-----------
+
+- Issue #3850: recursion tests in Misc/find_recursion_limit.py can raise
+  AttributeError instead of RuntimeError, depending in which C API call
+  exactly the recursion limit is exceeded. Consequently, both exception types
+  are caught and silenced.
+
 
 What's New in Python 2.6 release candidate 1?
 =============================================

Modified: python/trunk/Misc/find_recursionlimit.py
==============================================================================
--- python/trunk/Misc/find_recursionlimit.py	(original)
+++ python/trunk/Misc/find_recursionlimit.py	Sat Sep 13 22:30:30 2008
@@ -1,22 +1,30 @@
 #! /usr/bin/env python
 """Find the maximum recursion limit that prevents core dumps
 
 This script finds the maximum safe recursion limit on a particular
 platform.  If you need to change the recursion limit on your system,
 this script will tell you a safe upper bound.  To use the new limit,
-call sys.setrecursionlimit.
+call sys.setrecursionlimit().
 
 This module implements several ways to create infinite recursion in
 Python.  Different implementations end up pushing different numbers of
 C stack frames, depending on how many calls through Python's abstract
 C API occur.
 
-After each round of tests, it prints a message
-Limit of NNNN is fine.
+After each round of tests, it prints a message:
+"Limit of NNNN is fine".
 
-It ends when Python causes a segmentation fault because the limit is
-too high.  On platforms like Mac and Windows, it should exit with a
-MemoryError.
+The highest printed value of "NNNN" is therefore the highest potentially
+safe limit for your system (which depends on the OS, architecture, but also
+the compilation flags). Please note that it is practically impossible to
+test all possible recursion paths in the interpreter, so the results of
+this test should not be trusted blindly -- although they give a good hint
+of which values are reasonable.
+
+NOTE: When the C stack space allocated by your system is exceeded due
+to excessive recursion, exact behaviour depends on the platform, although
+the interpreter will always fail in a likely brutal way: either a
+segmentation fault, a MemoryError, or just a silent abort.
 
 NB: A program that does not use __methods__ can set a higher limit.
 """
@@ -88,7 +96,10 @@
     test_func = globals()[test_func_name]
     try:
         test_func()
-    except RuntimeError:
+    # AttributeError can be raised because of the way e.g. PyDict_GetItem()
+    # silences all exceptions and returns NULL, which is usually interpreted
+    # as "missing attribute".
+    except (RuntimeError, AttributeError):
         pass
     else:
         print "Yikes!"
@@ -1,22 +1,30 @@
 #! /usr/bin/env python
-"""Find the maximum recursion limit that prevents core dumps
+"""Find the maximum recursion limit that prevents interpreter termination.
 
 This script finds the maximum safe recursion limit on a particular


More information about the Python-checkins mailing list